@@ -305,17 +305,23 @@ Scalar::Util module, but there are a couple that provide functions not
 catered to by that module.
 
 Please use the versions in L<Scalar::Util> in preference to these
-functions.
+functions.  In fact, if you use these functions in your production
+code then you may have to rewrite it some day.  They are retained only
+because they are "mostly harmless".
 
 =over
 
 =item B<blessed>
 
+B<Do not use in production code>
+
 Returns a true value if the passed reference (RV) is blessed.  See
 also L<Acme::Holy>.
 
 =item B<reftype>
 
+B<Do not use in production code>
+
 A bit like the perl built-in C<ref> function, but returns the I<type>
 of reference; ie, if the reference is blessed then it returns what
 C<ref> would have if it were not blessed.  Useful for "seeing through"
@@ -323,12 +329,16 @@ blessed references.
 
 =item B<refaddr>
 
+B<Do not use in production code>
+
 Returns the memory address of a scalar.  B<Warning>: this is I<not>
 guaranteed to be unique for scalars created in a program; memory might
 get re-used!
 
 =item B<is_int>, B<is_string>, B<is_double>
 
+B<Do not use in production code>
+
 A quick way of checking the three bits on scalars - IOK (is_int), NOK
 (is_double) and POK (is_string).  Note that the exact behaviour of
 when these bits get set is not defined by the perl API.
@@ -338,10 +348,14 @@ with caution.
 
 =item B<is_overloaded>
 
+B<Do not use in production code>
+
 A quick way to check if an object has overload magic on it.
 
 =item B<ish_int>
 
+B<Deprecated and will be removed in 2014>
+
 This function returns true, if the value it is passed looks like it
 I<already is> a representation of an I<integer>.  This is so that you
 can decide whether the value passed is a hash key or an array
@@ -349,18 +363,16 @@ index.
 
 =item B<is_key>
 
-This function returns true, if the value it is passed looks more like
-an I<index> to a collection than a I<value> of a collection.
+B<Deprecated and will be removed in 2014>
 
-But wait, you say - Set::Object has no indices, one of the fundamental
-properties of a Set is that it is an I<unordered collection>.  Which
-means I<no indices>.  Well, if this module were ever to be derived to
-be a more general multi-purpose collection, then this (and C<ish_int>)
-might be a good function to use to distinguish different types of
-indexes from values.
+This function returns true, if the value it is passed looks more like
+an I<index> to a collection than a I<value> of a collection.  Similar
+to the looks_like_number internal function, but weird.  Avoid.
 
 =item B<get_magic>
 
+B<Do not use in production code>
+
 Pass to a scalar, and get the magick wand (C<mg_obj>) used by the weak
 set implementation.  The return will be a list of integers which are
 pointers to the actual C<ISET> structure.  Whatever you do don't
@@ -463,17 +475,18 @@ On my computer the results are:
 
 =head1 THREAD SAFETY
 
-This module has none.
+This module is not thread-safe.
 
 =head1 AUTHOR
 
 Original Set::Object module by Jean-Louis Leroy, <jll@skynet.be>
 
-Set::Scalar compatibility, XS debugging, weak references support and
-general maintainership courtesy of Sam Vilain, <samv@cpan.org>.
-Maximum respect to those who send me test scripts, enhancements, etc
-as patches against my git tree, browsable at
-L<http://utsl.gen.nz/gitweb/?p=Set-Object>.
+Set::Scalar compatibility, XS debugging, weak references support
+courtesy of Sam Vilain, <samv@cpan.org>.
+
+New maintainer is Reini Urban <rurban@cpan.org>.
+Patches against L<https://github.com/rurban/Set-Object/> please.
+Tickets at RT L<https://rt.cpan.org/Public/Dist/Display.html?Name=Set-Object>
 
 =head1 LICENCE
 
@@ -486,6 +499,8 @@ Portions Copyright (c) 2003 - 2005, Sam Vilain.  Same license.
 Portions Copyright (c) 2006, 2007, Catalyst IT (NZ) Limited.  Same
 license.
 
+Portions Copyright (c) 2013, cPanel.  Same license.
+
 =head1 SEE ALSO
 
 perl(1), perltie(1), L<Set::Scalar>, overload.pm
@@ -509,7 +524,7 @@ require AutoLoader;
 
 @EXPORT_OK = qw( ish_int is_int is_string is_double blessed reftype
 		 refaddr is_overloaded is_object is_key set weak_set );
-$VERSION = '1.25';
+$VERSION = '1.31';
 
 bootstrap Set::Object $VERSION;
 
@@ -898,6 +913,7 @@ sub tie_array_pkg { "Set::Object::TieArray" };
 # to be an array index, and if so returns the index
 sub ish_int {
     my $i;
+    local $@;
     eval { $i = _ish_int($_[0]) };
 
     if ($@) {
@@ -933,7 +949,7 @@ sub is_key {
 	    return is_key(&$sub($_[0]));
 	} elsif ($sub = UNIVERSAL::can($_[0], '(""')) {
 	    return is_key(&$sub($_[0]));
-	} elsif ($sub = UNIVERAL::can($_[0], '(nomethod')) {
+	} elsif ($sub = UNIVERSAL::can($_[0], '(nomethod')) {
 	    return is_key(&$sub($_[0]));
 	} else {
 	    return undef;
@@ -957,7 +973,6 @@ sub STORABLE_freeze {
 sub STORABLE_thaw {
     #print Dump $_ foreach (@_);
 
-    $DB::single = 1;
     if ( $_[2] ) {
 	if ( $_[2] eq "v2" ) {
 	    @_ = (@_[0,1], "", @{ $_[3] });
@@ -1074,6 +1089,7 @@ sub member {
 }
 
 sub set {
+    local $@;
     if (eval { $_[0]->isa(__PACKAGE__) }) {
     	shift;
     }
